@@ -8,7 +8,7 @@
 */
 
 #ifndef lint
-static char id[] = "@(#)$Id: smdb1.c,v 8.43.4.1 2000/08/24 17:08:00 gshapiro Exp $";
+static char id[] = "@(#)$Id: smdb1.c,v 8.43.4.3 2000/10/05 23:06:30 gshapiro Exp $";
 #endif /* ! lint */
 
 #include <unistd.h>
@@ -175,8 +175,12 @@ smdb1_del(database, key, flags)
 	u_int flags;
 {
 	DB *db = ((SMDB_DB1_DATABASE *) database->smdb_impl)->smdb1_db;
+	DBT dbkey;
 
-	return db->del(db, &key->db, flags);
+	memset(&dbkey, '\0', sizeof dbkey);
+	dbkey.data = key->data;
+	dbkey.size = key->size;
+	return db->del(db, &dbkey, flags);
 }
 
 int
@@ -212,14 +216,22 @@ smdb1_get(database, key, data, flags)
 {
 	int result;
 	DB *db = ((SMDB_DB1_DATABASE *) database->smdb_impl)->smdb1_db;
+	DBT dbkey, dbdata;
 
-	result = db->get(db, &key->db, &data->db, flags);
+	memset(&dbdata, '\0', sizeof dbdata);
+	memset(&dbkey, '\0', sizeof dbkey);
+	dbkey.data = key->data;
+	dbkey.size = key->size;
+
+	result = db->get(db, &dbkey, &dbdata, flags);
 	if (result != 0)
 	{
 		if (result == 1)
 			return SMDBE_NOT_FOUND;
 		return errno;
 	}
+	data->data = dbdata.data;
+	data->size = dbdata.size;
 	return SMDBE_OK;
 }
 
@@ -231,9 +243,17 @@ smdb1_put(database, key, data, flags)
 	u_int flags;
 {
 	DB *db = ((SMDB_DB1_DATABASE *) database->smdb_impl)->smdb1_db;
+	DBT dbkey, dbdata;
 
-	return db->put(db, &key->db, &data->db,
-			    smdb_put_flags_to_db1_flags(flags));
+	memset(&dbdata, '\0', sizeof dbdata);
+	memset(&dbkey, '\0', sizeof dbkey);
+	dbkey.data = key->data;
+	dbkey.size = key->size;
+	dbdata.data = data->data;
+	dbdata.size = data->size;
+
+	return db->put(db, &dbkey, &dbdata,
+		       smdb_put_flags_to_db1_flags(flags));
 }
 
 int
@@ -309,13 +329,21 @@ smdb1_cursor_get(cursor, key, value, flags)
 	SMDB_DB1_CURSOR *db1_cursor = (SMDB_DB1_CURSOR *) cursor->smdbc_impl;
 	SMDB_DB1_DATABASE *db1 = db1_cursor->db;
 	DB *db = db1->smdb1_db;
+	DBT dbkey, dbdata;
+
+	memset(&dbdata, '\0', sizeof dbdata);
+	memset(&dbkey, '\0', sizeof dbkey);
 
 	db1_flags = smdb_cursor_get_flags_to_smdb1(flags);
-	result = db->seq(db, &key->db, &value->db, db1_flags);
+	result = db->seq(db, &dbkey, &dbdata, db1_flags);
 	if (result == -1)
 		return errno;
 	if (result == 1)
 		return SMDBE_LAST_ENTRY;
+	value->data = dbdata.data;
+	value->size = dbdata.size;
+	key->data = dbkey.data;
+	key->size = dbkey.size;
 	return SMDBE_OK;
 }
 
@@ -329,8 +357,16 @@ smdb1_cursor_put(cursor, key, value, flags)
 	SMDB_DB1_CURSOR *db1_cursor = (SMDB_DB1_CURSOR *) cursor->smdbc_impl;
 	SMDB_DB1_DATABASE *db1 = db1_cursor->db;
 	DB *db = db1->smdb1_db;
+	DBT dbkey, dbdata;
 
-	return db->put(db, &key->db, &value->db, R_CURSOR);
+	memset(&dbdata, '\0', sizeof dbdata);
+	memset(&dbkey, '\0', sizeof dbkey);
+	dbkey.data = key->data;
+	dbkey.size = key->size;
+	dbdata.data = value->data;
+	dbdata.size = value->size;
+
+	return db->put(db, &dbkey, &dbdata, R_CURSOR);
 }
 
 int
